@@ -7,15 +7,12 @@
 
 #include "mazeitem.h"
 
-MazeItem::MazeItem() : QGraphicsSvgItem()
+MazeItem::MazeItem()
+    : QGraphicsSvgItem()
 {
     // Configure the cache in order to increase the performance
     setCacheMode(DeviceCoordinateCache);
     setMaximumCacheSize(QSize(2000, 2000));
 }
 
-MazeItem::~MazeItem()
-{
-
-}
-
+MazeItem::~MazeItem() = default;
